/*
 * Copyright 2023 by DTV-Verkehrsconsult, Aachen
 *
 * This file is part of de.bsvrz.ars.ars.
 *
 * de.bsvrz.ars.ars is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * de.bsvrz.ars.ars is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.ars.ars.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Contact Information:
 * DTV-Verkehrsconsult GmbH
 * Pascalstraße 53
 * 52076 Aachen, Germany
 * phone: +49 2408 7047 0
 * mail: <info@dtv-verkehrsconsult.de>
 */
package de.bsvrz.ars.ars.mgmt.commands;

import de.bsvrz.ars.ars.persistence.directories.PersistenceDirectory;
import de.bsvrz.ars.ars.persistence.directories.mgmt.TimeBasedPersistenceDirectoryManager;
import de.bsvrz.ars.ars.persistence.directories.mgmt.range.TimeRange;
import de.bsvrz.ars.ars.persistence.sequence.AllDataSpecification;
import de.bsvrz.sys.funclib.losb.util.cmdinterface.Command;

import java.util.List;

/**
 * Listet Persistenzverzeichnisse mit ihren Eigenschaften auf
 *
 * @param <T> Zeitbereichstyp
 */
public class ListPersistenceDirectoriesCommand<T extends TimeRange<T>> extends Command {
	private final TimeBasedPersistenceDirectoryManager<T> directoryManager;

	/**
	 * Erstellt einen neuen ListPersistenceDirectoriesCommand.
	 * @param directoryManager Verzeichnisverwaltung
	 */
	public ListPersistenceDirectoriesCommand(TimeBasedPersistenceDirectoryManager<T> directoryManager) {
		super("Verzeichnisse auflisten", "");
		this.directoryManager = directoryManager;
	}

	@Override
	public void execute() throws Exception {
		List<? extends PersistenceDirectory> persistenceDirectories = directoryManager.getPersistenceDirectories(0, AllDataSpecification.Instance);
		T prevTimeRange = null;
		for (PersistenceDirectory persistenceDirectory : persistenceDirectories) {
			T timeRange = directoryManager.getId(persistenceDirectory.getBasePath());
			while (prevTimeRange != null && !prevTimeRange.next().equals(timeRange)) {
				prevTimeRange = prevTimeRange.next();
				printlnPlain("  " + directoryManager.getDomain().getPath(prevTimeRange) + ": Verzeichnis fehlt.");
			}
			prevTimeRange = timeRange;
			printlnPlain("  " + directoryManager.getDomain().getPath(timeRange) + " mit mind. " + persistenceDirectory.estimate() + " Datenidentifikationen, davon " + persistenceDirectory.getLargeDataIdentifications().size() + " mit vielen Containerdateien.");
		}
	}
}
